Class: Melbourne::AST::Send
Overview
A method invocation (a message being sent) as in:
method()
Direct Known Subclasses
Instance Attribute Summary collapse
-
#block ⇒ Object
The block that is passed to the invocation if one is passed.
-
#check_for_local ⇒ Object
Returns the value of attribute check_for_local.
-
#name ⇒ Object
The message being sent/ method being invoked.
-
#privately ⇒ Object
Returns the value of attribute privately.
-
#receiver ⇒ Object
The receiver of the message/ invocation.
-
#variable ⇒ Object
Returns the value of attribute variable.
Attributes inherited from Node
Instance Method Summary collapse
-
#initialize(line, receiver, name, privately = false) ⇒ Send
constructor
A new instance of Send.
Methods inherited from Node
Constructor Details
#initialize(line, receiver, name, privately = false) ⇒ Send
Returns a new instance of Send.
29 30 31 32 33 34 35 36 |
# File 'lib/melbourne/ast/sends.rb', line 29 def initialize(line, receiver, name, privately=false) @line = line @receiver = receiver @name = name @privately = privately @block = nil @check_for_local = false end |
Instance Attribute Details
#block ⇒ Object
The block that is passed to the invocation if one is passed
23 24 25 |
# File 'lib/melbourne/ast/sends.rb', line 23 def block @block end |
#check_for_local ⇒ Object
Returns the value of attribute check_for_local.
27 28 29 |
# File 'lib/melbourne/ast/sends.rb', line 27 def check_for_local @check_for_local end |
#name ⇒ Object
The message being sent/ method being invoked
17 18 19 |
# File 'lib/melbourne/ast/sends.rb', line 17 def name @name end |
#privately ⇒ Object
Returns the value of attribute privately.
19 20 21 |
# File 'lib/melbourne/ast/sends.rb', line 19 def privately @privately end |
#receiver ⇒ Object
The receiver of the message/ invocation
13 14 15 |
# File 'lib/melbourne/ast/sends.rb', line 13 def receiver @receiver end |
#variable ⇒ Object
Returns the value of attribute variable.
25 26 27 |
# File 'lib/melbourne/ast/sends.rb', line 25 def variable @variable end |