Exception: Melbourne::ParserError

Inherits:
Exception
  • Object
show all
Defined in:
lib/melbourne/processor.rb

Overview

Exception that is raised whenever Melbourne encounters anything it cannot parse. When this exception is raised, the parsed code is most likely not syntactically valid.